# Generated by Django 4.2.8 on 2023-12-05 16:51

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("dashblocks", "0011_alter_dashblock_index_together_and_more"),
    ]

    operations = [
        migrations.RenameIndex(
            model_name="dashblock",
            new_name="dashblocks__org_id_024805_idx",
            old_fields=("org", "is_active", "dashblock_type", "priority"),
        ),
        migrations.RenameIndex(
            model_name="dashblocktype",
            new_name="dashblocks__slug_c0c6c6_idx",
            old_fields=("slug", "name"),
        ),
    ]
