{% extends "base.html" %}
{% block content %}
    <ul>
        {% for org in orgs %}
            %}
            <li>
                <a href="{{ org.host }}">{{ org.name }}</a>
            </li>
        {% endfor %}
    </ul>
{% endblock content %}
